@@ -48,7 +48,7 @@ class KToggleFullScreenAction;
  *
  * All of the documentation for QAction holds for KStandardAction
  * also.  When in doubt on how things work, check the QAction
- * documention first.
+ * documentation first.
  * Please note that calling any of these methods automatically adds the action
  * to the actionCollection() of the QObject given by the 'parent' parameter.
  *
@@ -129,48 +129,84 @@ namespace KStandardAction
  */
 enum StandardAction {
     ActionNone,
-
     // File Menu
-    New, Open, OpenRecent, Save, SaveAs, Revert, Close,
-    Print, PrintPreview, Mail, Quit,
-
+    New, ///< Create a new document or window.
+    Open, ///< Open an existing file.
+    OpenRecent, ///< Open a recently used document.
+    Save, ///< Save the current document.
+    SaveAs, ///< Save the current document under a different name.
+    Revert, ///< Revert the current document to the last saved version.
+    Close, ///< Close the current document.
+    Print, ///< Print the current document.
+    PrintPreview, ///< Show a print preview of the current document.
+    Mail, ///< Send the current document by mail.
+    Quit, ///< Quit the program.
     // Edit Menu
-    Undo, Redo, Cut, Copy, Paste, SelectAll, Deselect, Find, FindNext, FindPrev,
-    Replace,
-
+    Undo, ///< Undo the last operation.
+    Redo, ///< Redo the last operation.
+    Cut, ///< Cut selected area and store it in the clipboard.
+    Copy, ///< Copy selected area and store it in the clipboard.
+    Paste, ///< Paste the contents of clipboard at the current mouse or cursor.
+    SelectAll, ///< Select all elements in the current document.
+    Deselect, ///< Deselect any selected elements in the current document.
+    Find, ///< Initiate a 'find' request in the current document.
+    FindNext, ///< Find the next instance of a stored 'find'
+    FindPrev, ///< Find a previous instance of a stored 'find'.
+    Replace, ///< Find and replace matches.
     // View Menu
-    ActualSize, FitToPage, FitToWidth, FitToHeight, ZoomIn, ZoomOut,
-    Zoom, Redisplay,
-
+    ActualSize, ///< View the document at its actual size.
+    FitToPage, ///< Fit the document view to the size of the current window.
+    FitToWidth, ///< Fit the document view to the width of the current window.
+    FitToHeight, ///< Fit the document view to the height of the current window.
+    ZoomIn, ///< Zoom in the current document.
+    ZoomOut, ///< Zoom out the current document.
+    Zoom, ///< Select the current zoom level.
+    Redisplay, ///< Redisplay or redraw the document.
     // Go Menu
-    Up, Back, Forward, Home /*Home page*/, Prior, Next, Goto, GotoPage, GotoLine,
-    FirstPage, LastPage, DocumentBack, DocumentForward,
-
+    Up, ///< Move up (web style menu).
+    Back, ///< Move back (web style menu).
+    Forward, ///< Move forward (web style menu).
+    Home, ///< Go to the "Home" position or document.
+    Prior, ///< Scroll up one page.
+    Next, ///< Scroll down one page.
+    Goto, ///< Jump to some specific location in the document.
+    GotoPage, ///< Go to a specific page.
+    GotoLine, ///< Go to a specific line.
+    FirstPage, ///< Jump to the first page.
+    LastPage, ///< Jump to the last page.
+    DocumentBack, ///< Move back (document style menu).
+    DocumentForward, ///< Move forward (document style menu).
     // Bookmarks Menu
-    AddBookmark, EditBookmarks,
-
+    AddBookmark, ///< Add the current page to the bookmarks tree.
+    EditBookmarks, ///< Edit the application bookmarks.
     // Tools Menu
-    Spelling,
-
+    Spelling, ///< Pop up the spell checker.
     // Settings Menu
-    ShowMenubar, ShowToolbar, ShowStatusbar,
-    SaveOptions, KeyBindings,
-    Preferences, ConfigureToolbars,
-
+    ShowMenubar, ///< Show/Hide the menubar.
+    ShowToolbar, ///< Show/Hide the toolbar.
+    ShowStatusbar, ///< Show/Hide the statusbar.
+    SaveOptions, ///< @deprecated since 5.38
+    KeyBindings, ///< Display the configure key bindings dialog.
+    Preferences, ///< Display the preferences/options dialog.
+    ConfigureToolbars, ///< Display the toolbar configuration dialog.
     // Help Menu
-    Help, HelpContents, WhatsThis, ReportBug, AboutApp, AboutKDE,
-    TipofDay,
-
+    Help, ///< @deprecated since 5.38. Use HelpContents instead.
+    HelpContents, ///< Display the handbook of the application.
+    WhatsThis, ///< Trigger the What's This cursor.
+    ReportBug, ///< Open up the Report Bug dialog.
+    AboutApp, ///< Display the application's About box.
+    AboutKDE, ///< Display the About KDE dialog.
+    TipofDay, ///< Display the "Tip of the Day".
     // Other standard actions
-    ConfigureNotifications,
-    FullScreen,
-    Clear,
-    PasteText,
-    SwitchApplicationLanguage,
-    DeleteFile, //< @since 5.25
-    RenameFile, //< @since 5.25
-    MoveToTrash, //< @since 5.25
-    Donate //< @since 5.26
+    ConfigureNotifications, ///< Display the notifications configuration dialog.
+    FullScreen, ///< Switch to/from full screen mode.
+    Clear, ///< Clear the content of the focus widget.
+    PasteText, ///< @deprecated since 5.39. Use Paste instead.
+    SwitchApplicationLanguage, ///< Display the Switch Application Language dialog.
+    DeleteFile, ///< Permanently deletes files or folders. @since 5.25
+    RenameFile, ///< Renames files or folders. @since 5.25
+    MoveToTrash, ///< Moves files or folders to the trash. @since 5.25
+    Donate ///< Open donation page on kde.org. @since 5.26
 };
 
 /**
@@ -183,10 +219,10 @@ enum StandardAction {
  * KRecentFilesAction.
  *
  * @param id The StandardAction identifier to create a QAction for.
- * @param recvr The QObject to receive the signal, or 0 if no notification
+ * @param recvr The QObject to receive the signal, or @c nullptr if no notification
  *              is needed.
  * @param slot  The slot to connect the signal to (remember to use the SLOT() macro).
- * @param parent The QObject that should own the created QAction, or 0 if no parent will
+ * @param parent The QObject that should own the created QAction, or @c nullptr if no parent will
  *               own the QAction returned (ensure you delete it manually in this case).
  */
 KCONFIGWIDGETS_EXPORT QAction *create(StandardAction id, const QObject *recvr, const char *slot,
@@ -205,7 +241,7 @@ KCONFIGWIDGETS_EXPORT QAction *_k_createInternal(StandardAction id, QObject *par
  * @since 5.23
  */
 #ifdef DOXYGEN_SHOULD_SKIP_THIS
-inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject* parent);
+inline QAction *create(StandardAction id, const QObject *recvr, Func slot, QObject* parent)
 #else
 template<class Receiver, class Func>
 inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *create(StandardAction id, const Receiver *recvr, Func slot, QObject *parent)
@@ -236,7 +272,7 @@ inline KCONFIGWIDGETS_DEPRECATED const char *stdName(StandardAction act_enum)
 
 /**
  * Returns a list of all standard names. Used by KAccelManager
- * to give those heigher weight.
+ * to give those higher weight.
  */
 KCONFIGWIDGETS_EXPORT QStringList stdNames();
 
@@ -250,7 +286,7 @@ KCONFIGWIDGETS_EXPORT QList<StandardAction> actionIds();
 /**
  * Returns the standardshortcut associated with @a actionId.
  *
- * @param actionId    The actionId whose associated shortcut is wanted.
+ * @param id    The identifier whose associated shortcut is wanted.
  *
  * @since 4.2
  */
@@ -389,7 +425,7 @@ KCONFIGWIDGETS_EXPORT QAction *printPreview(const QObject *recvr, const char *sl
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(printPreview, PrintPreview)
 
 /**
- * Mail this document.
+ * Send the current document by mail.
  */
 KCONFIGWIDGETS_EXPORT QAction *mail(const QObject *recvr, const char *slot, QObject *parent);
 
@@ -460,7 +496,7 @@ KCONFIGWIDGETS_EXPORT QAction *paste(QObject *parent);
  * Clear selected area.  Calls clear() on the widget with the current focus.
  * Note that for some widgets, this may not provide the intended behavior.  For
  * example if you make use of the code above and a K3ListView has the focus, clear()
- * will clear all of the items in the list.  If this is not the intened behavior
+ * will clear all of the items in the list.  If this is not the intended behavior
  * and you want to make use of this slot, you can subclass K3ListView and reimplement
  * this slot.  For example the following code would implement a K3ListView without this
  * behavior:
@@ -519,19 +555,25 @@ KCONFIGWIDGETS_EXPORT QAction *paste(const QObject *recvr, const char *slot, QOb
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(paste, Paste)
 
 /**
- * Paste the contents of clipboard at the current mouse or cursor
- * position. Provide a button on the toolbar with the clipboard history
- * menu if Klipper is running.
+ * @deprecated since 5.39. Use paste() instead.
  */
-KCONFIGWIDGETS_EXPORT QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent);
+#ifndef KDE_NO_DEPRECATED
+KCONFIGWIDGETS_DEPRECATED_EXPORT QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent);
+#endif
 
 /**
- * Paste the contents of clipboard at the current mouse or cursor
- * position. Provide a button on the toolbar with the clipboard history
- * menu if Klipper is running.
  * @since 5.23
+ * @deprecated since 5.39. Use paste() instead.
  */
-KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(pasteText, PasteText)
+#ifndef KDE_NO_DEPRECATED
+#ifdef DOXYGEN_SHOULD_SKIP_THIS
+    inline QAction *pasteText(const QObject *recvr, Func slot, QObject *parent);
+#else
+template<class Receiver, class Func>
+KCONFIGWIDGETS_DEPRECATED_EXPORT inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *pasteText(const Receiver *recvr, Func slot, QObject *parent)
+{ return create(PasteText, recvr, slot, parent); }
+#endif // DOXYGEN_SHOULD_SKIP_THIS
+#endif // KDE_NO_DEPRECATED
 
 /**
  * Clear the content of the focus widget
@@ -655,34 +697,34 @@ KCONFIGWIDGETS_EXPORT QAction *fitToHeight(const QObject *recvr, const char *slo
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(fitToHeight, FitToHeight)
 
 /**
- * Zoom in.
+ * Zoom in the current document view.
  */
 KCONFIGWIDGETS_EXPORT QAction *zoomIn(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Zoom in.
+ * Zoom in the current document view.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(zoomIn, ZoomIn)
 
 /**
- * Zoom out.
+ * Zoom out the current document view.
  */
 KCONFIGWIDGETS_EXPORT QAction *zoomOut(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Zoom out.
+ * Zoom out the current document view.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(zoomOut, ZoomOut)
 
 /**
- * Popup a zoom dialog.
+ * Select the current zoom level.
  */
 KCONFIGWIDGETS_EXPORT QAction *zoom(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Popup a zoom dialog.
+ * Select the current zoom level.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(zoom, Zoom)
@@ -765,34 +807,34 @@ KCONFIGWIDGETS_EXPORT QAction *next(const QObject *recvr, const char *slot, QObj
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(next, Next)
 
 /**
- * Go to somewhere in general.
+ * Jump to some specific location in the document.
  */
 KCONFIGWIDGETS_EXPORT QAction *goTo(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Go to somewhere in general.
+ * Jump to some specific location in the document.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(goTo, Goto)
 
 /**
- * Go to a specific page (dialog).
+ * Go to a specific page.
  */
 KCONFIGWIDGETS_EXPORT QAction *gotoPage(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Go to a specific page (dialog).
+ * Go to a specific page.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(gotoPage, GotoPage)
 
 /**
- * Go to a specific line (dialog).
+ * Go to a specific line.
  */
 KCONFIGWIDGETS_EXPORT QAction *gotoLine(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Go to a specific line (dialog).
+ * Go to a specific line.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(gotoLine, GotoLine)
@@ -879,8 +921,18 @@ KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(spelling, Spelling)
  */
 KCONFIGWIDGETS_EXPORT KToggleAction *showMenubar(const QObject *recvr, const char *slot, QObject *parent);
 
+/**
+ * The same as showMenubar(const QObject *, const char *, QObject *), but using new-style connect syntax
+ * @see showMenubar(const QObject *, const char *, QObject *)
+ * @since 5.23
+ */
+#ifdef DOXYGEN_SHOULD_SKIP_THIS
+inline KToggleAction *showMenubar(const QObject *recvr, Func slot, QObject *parent)
+#else
 template<class Receiver, class Func>
-inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleAction>::type *showMenubar(const Receiver *recvr, Func slot, QObject *parent) {
+inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleAction>::type *showMenubar(const Receiver *recvr, Func slot, QObject *parent)
+#endif
+{
     QAction* ret = create(ShowMenubar, recvr, slot, parent);
     Q_ASSERT(qobject_cast<KToggleAction *>(ret));
     return static_cast<KToggleAction *>(ret);
@@ -893,6 +945,7 @@ KCONFIGWIDGETS_EXPORT KToggleAction *showStatusbar(const QObject *recvr, const c
 
 /**
  * Show/Hide the statusbar.
+ * @since 5.23
  */
 #ifdef DOXYGEN_SHOULD_SKIP_THIS
 inline KToggleAction *showStatusbar(const QObject *recvr, Func slot, QObject *parent)
@@ -916,7 +969,7 @@ KCONFIGWIDGETS_EXPORT KToggleFullScreenAction *fullScreen(const QObject *recvr,
  * @since 5.23
  */
 #ifdef DOXYGEN_SHOULD_SKIP_THIS
-inline KToggleFullScreenAction *fullScreen(const QObject *recvr, Func slot, QWidget *window, QObject *parent);
+inline KToggleFullScreenAction *fullScreen(const QObject *recvr, Func slot, QWidget *window, QObject *parent)
 #else
 template<class Receiver, class Func>
 inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, KToggleFullScreenAction>::type *fullScreen(const Receiver *recvr, Func slot, QWidget *window, QObject *parent)
@@ -931,14 +984,26 @@ inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, K
 
 /**
  * Display the save options dialog.
+ * @deprecated since 5.38
  */
-KCONFIGWIDGETS_EXPORT QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent);
+#ifndef KDE_NO_DEPRECATED
+KCONFIGWIDGETS_DEPRECATED_EXPORT QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent);
+#endif
 
 /**
  * Display the save options dialog.
  * @since 5.23
+ * @deprecated since 5.38
  */
-KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(saveOptions, SaveOptions)
+#ifndef KDE_NO_DEPRECATED
+#ifdef DOXYGEN_SHOULD_SKIP_THIS
+    inline QAction *saveOptions(const QObject *recvr, Func slot, QObject *parent);
+#else
+template<class Receiver, class Func>
+KCONFIGWIDGETS_DEPRECATED_EXPORT inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *saveOptions(const Receiver *recvr, Func slot, QObject *parent)
+{ return create(SaveOptions, recvr, slot, parent); }
+#endif // DOXYGEN_SHOULD_SKIP_THIS
+#endif // KDE_NO_DEPRECATED
 
 /**
  * Display the configure key bindings dialog.
@@ -967,45 +1032,55 @@ KCONFIGWIDGETS_EXPORT QAction *preferences(const QObject *recvr, const char *slo
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(preferences, Preferences)
 
 /**
- * The Customize Toolbar dialog.
+ * Display the toolbar configuration dialog.
  */
 KCONFIGWIDGETS_EXPORT QAction *configureToolbars(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * The Customize Toolbar dialog.
+ * Display the toolbar configuration dialog.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(configureToolbars, ConfigureToolbars)
 
 /**
- * The Configure Notifications dialog.
+ * Display the notifications configuration dialog.
  */
 KCONFIGWIDGETS_EXPORT QAction *configureNotifications(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * The Configure Notifications dialog.
+ * Display the notifications configuration dialog.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(configureNotifications, ConfigureNotifications)
 
 /**
- * Display the help.
+ * @deprecated since 5.38 Use helpContents() instead.
  */
-KCONFIGWIDGETS_EXPORT QAction *help(const QObject *recvr, const char *slot, QObject *parent);
+#ifndef KDE_NO_DEPRECATED
+KCONFIGWIDGETS_DEPRECATED_EXPORT QAction *help(const QObject *recvr, const char *slot, QObject *parent);
+#endif
 
 /**
- * Display the help.
  * @since 5.23
+ * @deprecated since 5.38 Use helpContents() instead.
  */
-KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(help, Help)
+#ifndef KDE_NO_DEPRECATED
+#ifdef DOXYGEN_SHOULD_SKIP_THIS
+    inline QAction *help(const QObject *recvr, Func slot, QObject *parent);
+#else
+template<class Receiver, class Func>
+KCONFIGWIDGETS_DEPRECATED_EXPORT inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *help(const Receiver *recvr, Func slot, QObject *parent)
+{ return create(Help, recvr, slot, parent); }
+#endif // DOXYGEN_SHOULD_SKIP_THIS
+#endif // KDE_NO_DEPRECATED
 
 /**
- * Display the help contents.
+ * Display the handbook of the application.
  */
 KCONFIGWIDGETS_EXPORT QAction *helpContents(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Display the help contents.
+ * Display the handbook of the application.
  * @since 5.23
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(helpContents, HelpContents)
@@ -1066,37 +1141,37 @@ KCONFIGWIDGETS_EXPORT QAction *aboutKDE(const QObject *recvr, const char *slot,
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(aboutKDE, AboutKDE)
 
 /**
- * Delete file.
+ * Permanently deletes files or folders.
  * @since 5.25
  */
 KCONFIGWIDGETS_EXPORT QAction *deleteFile(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Delete file.
+ * Permanently deletes files or folders.
  * @since 5.25
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(deleteFile, DeleteFile)
 
 /**
- * Rename file.
+ * Renames files or folders.
  * @since 5.25
  */
 KCONFIGWIDGETS_EXPORT QAction *renameFile(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Rename file.
+ * Renames files or folders.
  * @since 5.25
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(renameFile, RenameFile)
 
 /**
- * Move to Trash.
+ * Moves files or folders to the trash.
  * @since 5.25
  */
 KCONFIGWIDGETS_EXPORT QAction *moveToTrash(const QObject *recvr, const char *slot, QObject *parent);
 
 /**
- * Move to Trash.
+ * Moves files or folders to the trash.
  * @since 5.25
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(moveToTrash, MoveToTrash)
